﻿using Vintagestory.API.Common;
using Vintagestory.API.Common.Entities;
using Vintagestory.API.MathTools;

namespace FreeStoneDropsWhenBrokenMod
{
    public class BlockBehaviorFreeStoneDropsWhenBroken : BlockBehavior
    {
        public BlockBehaviorFreeStoneDropsWhenBroken(Block block) : base(block)
        {
        }

        public override ItemStack[] GetDrops(IWorldAccessor world, BlockPos pos, IPlayer byPlayer, ref float dropQuantityMultiplier, ref EnumHandling handling)
        // Similar to `BehaviorBreakIfFloating.GetDrops`.
        {
            if(BlockHasOnlyOneSupport(world, pos))
            {
                handling = EnumHandling.PreventSubsequent;
                return new ItemStack[] { new ItemStack(block) };
            }
            else
            {
                return base.GetDrops(world, pos, byPlayer, ref dropQuantityMultiplier, ref handling);
            }
        }

        protected bool BlockHasOnlyOneSupport(IWorldAccessor world, BlockPos pos)
        // Check whether 5 out of 6 neighbours are non-solid.
        {
			int freeFaces = 0;
            foreach(BlockFacing facing in BlockFacing.ALLFACES)
            {
                if (!world.BlockAccessor.IsSideSolid(pos.X + facing.Normali.X, pos.Y + facing.Normali.Y, pos.Z + facing.Normali.Z, facing.Opposite))
				    {
						freeFaces += 1;
				    }
            }
            return freeFaces == 5;
        }
    }
}